@@ -4,18 +4,11 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import List, Optional, Union
 
-from great_expectations.core import ExpectationConfiguration
-from great_expectations.core.expectation_diagnostics.expectation_test_data_cases import (
-    ExpectationTestCase,
-    TestData,
-)
 from great_expectations.core.expectation_validation_result import (
     ExpectationValidationResult,
 )
 from great_expectations.types import SerializableDictDot
 
-# from pydantic.dataclasses import dataclass
-
 
 class Maturity(Enum):
     """The four levels of maturity for features within Great Expectations"""
@@ -120,6 +113,14 @@ class ExpectationExecutionEngineDiagnostics(SerializableDictDot):
     SparkDFExecutionEngine: bool
 
 
+@dataclass
+class ExpectationErrorDiagnostics(SerializableDictDot):
+    error_msg: str
+    stack_trace: str
+    test_title: Optional[str] = None
+    test_backend: Optional[str] = None
+
+
 @dataclass
 class ExpectationTestDiagnostics(SerializableDictDot):
     """Captures information from executing Expectation test cases. Used within the ExpectationDiagnostic object."""
@@ -127,30 +128,21 @@ class ExpectationTestDiagnostics(SerializableDictDot):
     test_title: str
     backend: str
     test_passed: bool
-    error_message: Union[str, None] = None
-    stack_trace: Union[str, None] = None
-
-
-@dataclass
-class ExpectationErrorDiagnostics(SerializableDictDot):
-    error_msg: str
-    stack_trace: str
-
-
-@dataclass
-class ExecutedExpectationTestCase(SerializableDictDot):
-    """Captures information from executing Expectation test cases. Used within the ExpectationDiagnostic object.
-
-    This may turn out to be the same thing as ExpectationTestDiagnostics.
-    """
-
-    data: TestData
-    test_case: ExpectationTestCase
-    expectation_configuration: ExpectationConfiguration
+    include_in_gallery: bool
     validation_result: ExpectationValidationResult
     error_diagnostics: ExpectationErrorDiagnostics
 
 
+@dataclass
+class ExpectationBackendTestResultCounts(SerializableDictDot):
+    """Has each tested backend and the number of passing/failing tests"""
+
+    backend: str
+    num_passed: int
+    num_failed: int
+    failing_names: Optional[List[str]]
+
+
 @dataclass
 class ExpectationDiagnosticCheckMessage(SerializableDictDot):
     """Summarizes the result of a diagnostic Check. Used within the ExpectationDiagnostic object."""
