@@ -43,6 +43,7 @@ class GEDependencies:
             "jsonpatch",
             "jsonschema",
             "makefun",
+            "marshmallow",
             "mistune",
             "nbformat",
             "notebook",
@@ -97,12 +98,12 @@ class GEDependencies:
             "pyspark",
             "pytest",
             "pytest-benchmark",
-            "pytest-azurepipelines",
             "pytest-cov",
             "pytest-mock",
             "pytest-icdiff",
             "pytest-order",
             "pytest-random-order",
+            "pytest-timeout",
             "pyupgrade",
             "requirements-parser",
             "s3fs",
@@ -128,6 +129,7 @@ class GEDependencies:
         "pre-commit",
         "pytest-cov",
         "pytest-order",
+        "pytest-random-order",
         "pyupgrade",
         # requirements-dev-lite.txt:
         "flask",
@@ -141,6 +143,7 @@ class GEDependencies:
         "pytest-benchmark",
         "pytest-mock",
         "pytest-icdiff",
+        "pytest-timeout",
         "requirements-parser",
         "s3fs",
         "snapshottest",
@@ -149,9 +152,57 @@ class GEDependencies:
         "PyHive",
         "thrift",
         "thrift-sasl",
-        # requirements-dev-test-pipeline.txt:
-        "pytest-azurepipelines",
-        "pytest-random-order",
+        # requirements-dev-tools.txt
+        "jupyter",
+        "jupyterlab",
+        "matplotlib",
+        # requirements-dev-all-contrib-expectations.txt
+        "arxiv",
+        "barcodenumber",
+        "blockcypher",
+        "coinaddrvalidator",
+        "cryptoaddress",
+        "cryptocompare",
+        "dataprofiler",
+        "disposable_email_domains",
+        "dnspython",
+        "edtf_validate",
+        "ephem",
+        "geonamescache",
+        "geopandas",
+        "geopy",
+        "global-land-mask",
+        "gtin",
+        "holidays",
+        "ipwhois",
+        "isbnlib",
+        "langid",
+        "pgeocode",
+        "phonenumbers",
+        "price_parser",
+        "primefac",
+        "pwnedpasswords",
+        "py-moneyed",
+        "pydnsbl",
+        "pygeos",
+        "pyogrio",
+        "python-geohash",
+        "python-stdnum",
+        "pyvat",
+        "rtree",
+        "schwifty",
+        "scikit-learn",
+        "shapely",
+        "simple_icd_10",
+        "sklearn",
+        "sympy",
+        "tensorflow",
+        "timezonefinder",
+        "us",
+        "user_agents",
+        "uszipcode",
+        "yahoo_fin",
+        "zipcodes",
     ]
 
     GE_DEV_DEPENDENCIES: List[str] = set(ALL_GE_DEV_DEPENDENCIES) - set(
