@@ -131,7 +131,7 @@ class FileDataContext(AbstractDataContext):
         )
         if include_rendered_content:
             expectation_suite.render()
-        return self.expectations_store.set(key, expectation_suite, **kwargs)
+        return self.expectations_store.set(key, expectation_suite, **kwargs)  # type: ignore[arg-type]
 
     @property
     def root_directory(self) -> Optional[str]:
