@@ -1,3 +1,4 @@
+import json
 import logging
 from typing import Any
 
@@ -31,4 +32,4 @@ class NumericSorter(Sorter):
             "reverse": self.reverse,
             "type": "NumericSorter",
         }
-        return str(doc_fields_dict)
+        return json.dumps(doc_fields_dict, indent=2)
