@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import enum
-from typing import Any, List
+from typing import Any, List, Union
 
 
 class GESqlDialect(enum.Enum):
@@ -24,6 +24,14 @@ class GESqlDialect(enum.Enum):
     TRINO = "trino"
     OTHER = "other"
 
+    def __eq__(self, other: Union[str, GESqlDialect]):
+        if isinstance(other, str):
+            return self.value.lower() == other.lower()
+        return self.value.lower() == other.value.lower()
+
+    def __hash__(self: GESqlDialect):
+        return hash(self.value)
+
     @classmethod
     def _missing_(cls, value: Any) -> None:
         try:
