@@ -172,7 +172,7 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             + values_string
         )
 
-        if params["mostly"] is not None:
+        if params["mostly"] is not None and params["mostly"] < 1.0:
             params_with_json_schema["mostly_pct"]["value"] = num_to_str(
                 params["mostly"] * 100, precision=15, no_scientific=True
             )
@@ -237,7 +237,7 @@ class ExpectColumnValuesToNotMatchRegexList(ColumnMapExpectation):
             + values_string
         )
 
-        if params["mostly"] is not None:
+        if params["mostly"] is not None and params["mostly"] < 1.0:
             params["mostly_pct"] = num_to_str(
                 params["mostly"] * 100, precision=15, no_scientific=True
             )
