@@ -1,7 +1,7 @@
 import warnings
 
 # noinspection PyUnresolvedReferences
-from great_expectations.expectations.metrics.column_aggregate_metric_provider import *
+from great_expectations.expectations.metrics.column_aggregate_metric_provider import *  # noqa: F401
 
 # deprecated-v0.13.25
 warnings.warn(
