@@ -30,9 +30,11 @@ class ColumnValuesInSet(ColumnMapMetricProvider):
             kwargs.get("parse_strings_as_datetimes") or False
         )
         if parse_strings_as_datetimes:
+            # deprecated-v0.13.41
             warnings.warn(
-                f"""The parameter "parse_strings_as_datetimes" is no longer supported and will be deprecated in a \
-future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._pandas()", it is not used.
+                """The parameter "parse_strings_as_datetimes" is deprecated as of v0.13.41 in \
+v0.16. As part of the V3 API transition, we've moved away from input transformation. For more information, \
+please see: https://greatexpectations.io/blog/why_we_dont_do_transformations_for_expectations/
 """,
                 DeprecationWarning,
             )
@@ -55,9 +57,11 @@ future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._
             kwargs.get("parse_strings_as_datetimes") or False
         )
         if parse_strings_as_datetimes:
+            # deprecated-v0.13.41
             warnings.warn(
-                f"""The parameter "parse_strings_as_datetimes" is no longer supported and will be deprecated in a \
-future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._sqlalchemy()", it is not used.
+                """The parameter "parse_strings_as_datetimes" is deprecated as of v0.13.41 in \
+v0.16. As part of the V3 API transition, we've moved away from input transformation. For more information, \
+please see: https://greatexpectations.io/blog/why_we_dont_do_transformations_for_expectations/
 """,
                 DeprecationWarning,
             )
@@ -83,9 +87,11 @@ future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._
             kwargs.get("parse_strings_as_datetimes") or False
         )
         if parse_strings_as_datetimes:
+            # deprecated-v0.13.41
             warnings.warn(
-                f"""The parameter "parse_strings_as_datetimes" is no longer supported and will be deprecated in a \
-future release.  Please update code accordingly.  Moreover, in "{cls.__name__}._spark()", it is not used.
+                """The parameter "parse_strings_as_datetimes" is deprecated as of v0.13.41 in \
+v0.16. As part of the V3 API transition, we've moved away from input transformation. For more information, \
+please see: https://greatexpectations.io/blog/why_we_dont_do_transformations_for_expectations/
 """,
                 DeprecationWarning,
             )
