@@ -28,7 +28,7 @@ class ColumnValuesNotMatchRegex(ColumnMapMetricProvider):
             column, regex, _dialect, positive=False
         )
         if regex_expression is None:
-            logger.warning("Regex is not supported for dialect %s" % str(_dialect))
+            logger.warning(f"Regex is not supported for dialect {str(_dialect)}")
             raise NotImplementedError
 
         return regex_expression
