@@ -3,7 +3,7 @@ import logging
 import time
 import warnings
 from enum import Enum
-from typing import Any
+from typing import Any, Optional
 
 from dateutil.parser import parse
 
@@ -144,20 +144,22 @@ class Profiler(metaclass=abc.ABCMeta):
       kind of object. You should raise an appropriate Exception if the object is not valid.
     """
 
-    def __init__(self, configuration: dict = None) -> None:
+    def __init__(self, configuration: Optional[dict] = None) -> None:
         self.configuration = configuration
 
     def validate(self, item_to_validate: Any) -> None:
         pass
 
-    def profile(self, item_to_profile: Any, suite_name: str = None) -> ExpectationSuite:
+    def profile(
+        self, item_to_profile: Any, suite_name: Optional[str] = None
+    ) -> ExpectationSuite:
         self.validate(item_to_profile)
         expectation_suite = self._profile(item_to_profile, suite_name=suite_name)
         return expectation_suite
 
     @abc.abstractmethod
     def _profile(
-        self, item_to_profile: Any, suite_name: str = None
+        self, item_to_profile: Any, suite_name: Optional[str] = None
     ) -> ExpectationSuite:
         pass
 
