@@ -1,4 +1,5 @@
 from functools import wraps
+from typing import Any
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_validation_result import (
@@ -25,10 +26,6 @@ class Renderer:
         # used to be composed exclusively of classmethods
         pass
 
-    @classmethod
-    def render(cls, ge_object):
-        return ge_object
-
     @classmethod
     def _get_expectation_type(cls, ge_object):
         if isinstance(ge_object, ExpectationConfiguration):
@@ -115,3 +112,9 @@ class Renderer:
             columns[column].append(evr)
 
         return columns
+
+    def render(self, **kwargs: dict) -> Any:
+        """
+        Render interface method.
+        """
+        raise NotImplementedError
