@@ -29,11 +29,11 @@ from great_expectations.rule_based_profiler.helpers.runtime_environment import (
 )
 from great_expectations.rule_based_profiler.helpers.util import sanitize_parameter_name
 from great_expectations.rule_based_profiler.parameter_builder import (
+    HistogramSingleBatchParameterBuilder,
     MeanUnexpectedMapMetricMultiBatchParameterBuilder,
     MetricMultiBatchParameterBuilder,
     NumericMetricRangeMultiBatchParameterBuilder,
     ParameterBuilder,
-    PartitionParameterBuilder,
 )
 from great_expectations.rule_based_profiler.parameter_builder.regex_pattern_string_parameter_builder import (
     RegexPatternStringParameterBuilder,
@@ -361,17 +361,15 @@ class DataAssistant(metaclass=MetaDataAssistant):
             )
 
         @staticmethod
-        def build_partition_parameter_builder(
+        def build_histogram_single_batch_parameter_builder(
             name: str,
-            bucketize_data: Union[str, bool] = True,
-        ) -> PartitionParameterBuilder:
+        ) -> HistogramSingleBatchParameterBuilder:
             """
-            This method instantiates "PartitionParameterBuilder" class with specific arguments for given purpose.
+            This method instantiates "HistogramSingleBatchParameterBuilder" class with specific arguments for given purpose.
             """
             name: str = sanitize_parameter_name(name=f"{name}")
-            return PartitionParameterBuilder(
+            return HistogramSingleBatchParameterBuilder(
                 name=name,
-                bucketize_data=bucketize_data,
                 evaluation_parameter_builder_configs=None,
                 data_context=None,
             )
@@ -681,6 +679,7 @@ configuration included.
 
 
 def build_map_metric_rule(
+    data_assistant_class_name: str,
     rule_name: str,
     expectation_type: str,
     map_metric_name: str,
@@ -727,17 +726,40 @@ def build_map_metric_rule(
         )
     )
 
-    # Step-2: Declare "ParameterBuilder" for every metric of interest.
+    # Step-2: Declare "ParameterBuilder" for every relevant metric of interest.
 
-    column_values_unique_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
-        DataAssistant.commonly_used_parameter_builders.get_column_values_unique_unexpected_count_metric_multi_batch_parameter_builder()
-    )
-    column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
-        DataAssistant.commonly_used_parameter_builders.get_column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder()
-    )
-    column_values_null_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
-        DataAssistant.commonly_used_parameter_builders.get_column_values_null_unexpected_count_metric_multi_batch_parameter_builder()
-    )
+    parameter_builders: List[ParameterBuilder] = []
+
+    column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_evaluations: Optional[
+        ParameterBuilder
+    ] = None
+
+    if map_metric_name == "column_values.unique":
+        column_values_unique_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
+            DataAssistant.commonly_used_parameter_builders.get_column_values_unique_unexpected_count_metric_multi_batch_parameter_builder()
+        )
+        parameter_builders.append(
+            column_values_unique_unexpected_count_metric_multi_batch_parameter_builder_for_metrics
+        )
+    elif map_metric_name == "column_values.null":
+        column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
+            DataAssistant.commonly_used_parameter_builders.get_column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder()
+        )
+        column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_evaluations = column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_metrics
+        parameter_builders.append(
+            column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_metrics
+        )
+    elif map_metric_name == "column_values.nonnull":
+        column_values_null_unexpected_count_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
+            DataAssistant.commonly_used_parameter_builders.get_column_values_null_unexpected_count_metric_multi_batch_parameter_builder()
+        )
+        parameter_builders.append(
+            column_values_null_unexpected_count_metric_multi_batch_parameter_builder_for_metrics
+        )
+    else:
+        raise ValueError(
+            f"""Metric "{map_metric_name}" is not supported as part of "{data_assistant_class_name}" implementation."""
+        )
 
     # Step-3: Set up "MeanUnexpectedMapMetricMultiBatchParameterBuilder" to compute "condition" for emitting "ExpectationConfiguration" (based on "Domain" data).
 
@@ -746,9 +768,14 @@ def build_map_metric_rule(
             DataAssistant.commonly_used_parameter_builders.get_table_row_count_metric_multi_batch_parameter_builder()
         )
 
-    column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_evaluations: ParameterBuilder = (
-        DataAssistant.commonly_used_parameter_builders.get_column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder()
-    )
+    if (
+        column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_evaluations
+        is None
+    ):
+        column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_evaluations = (
+            DataAssistant.commonly_used_parameter_builders.get_column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder()
+        )
+
     evaluation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]] = [
         ParameterBuilderConfig(
             **total_count_metric_multi_batch_parameter_builder_for_evaluations.to_json_dict()
@@ -791,11 +818,6 @@ def build_map_metric_rule(
         "success_ratio": 7.5e-1,
     }
 
-    parameter_builders: List[ParameterBuilder] = [
-        column_values_unique_unexpected_count_metric_multi_batch_parameter_builder_for_metrics,
-        column_values_nonnull_unexpected_count_metric_multi_batch_parameter_builder_for_metrics,
-        column_values_null_unexpected_count_metric_multi_batch_parameter_builder_for_metrics,
-    ]
     expectation_configuration_builders: List[ExpectationConfigurationBuilder] = [
         expect_column_values_to_be_attribute_expectation_configuration_builder,
     ]
