@@ -76,6 +76,7 @@ class OnboardingDataAssistant(DataAssistant):
         )
 
         column_value_uniqueness_rule: Rule = build_map_metric_rule(
+            data_assistant_class_name=self.__class__.__name__,
             rule_name="column_value_uniqueness_rule",
             expectation_type="expect_column_values_to_be_unique",
             map_metric_name="column_values.unique",
@@ -93,6 +94,7 @@ class OnboardingDataAssistant(DataAssistant):
             min_max_unexpected_values_proportion=9.75e-1,
         )
         column_value_nullity_rule: Rule = build_map_metric_rule(
+            data_assistant_class_name=self.__class__.__name__,
             rule_name="column_value_nullity_rule",
             expectation_type="expect_column_values_to_be_null",
             map_metric_name="column_values.null",
@@ -110,6 +112,7 @@ class OnboardingDataAssistant(DataAssistant):
             min_max_unexpected_values_proportion=9.75e-1,
         )
         column_value_nonnullity_rule: Rule = build_map_metric_rule(
+            data_assistant_class_name=self.__class__.__name__,
             rule_name="column_value_nonnullity_rule",
             expectation_type="expect_column_values_to_not_be_null",
             map_metric_name="column_values.nonnull",
@@ -285,6 +288,7 @@ class OnboardingDataAssistant(DataAssistant):
             include_column_name_suffixes=None,
             exclude_column_name_suffixes=[
                 "_id",
+                "_ID",
             ],
             semantic_type_filter_module_name=None,
             semantic_type_filter_class_name=None,
@@ -299,9 +303,8 @@ class OnboardingDataAssistant(DataAssistant):
 
         # Step-2: Declare "ParameterBuilder" for every metric of interest.
 
-        column_partition_parameter_builder_for_metrics: ParameterBuilder = DataAssistant.commonly_used_parameter_builders.build_partition_parameter_builder(
+        column_histogram_single_batch_parameter_builder_for_metrics: ParameterBuilder = DataAssistant.commonly_used_parameter_builders.build_histogram_single_batch_parameter_builder(
             name="column_values.partition",
-            bucketize_data=True,
         )
         column_min_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
             DataAssistant.commonly_used_parameter_builders.get_column_min_metric_multi_batch_parameter_builder()
@@ -557,10 +560,10 @@ class OnboardingDataAssistant(DataAssistant):
                 "lower_bound": None,
                 "upper_bound": None,
             },
-            "round_decimals": 15,
+            "round_decimals": None,
         }
         parameter_builders: List[ParameterBuilder] = [
-            column_partition_parameter_builder_for_metrics,
+            column_histogram_single_batch_parameter_builder_for_metrics,
             column_min_metric_multi_batch_parameter_builder_for_metrics,
             column_max_metric_multi_batch_parameter_builder_for_metrics,
             column_quantile_values_metric_multi_batch_parameter_builder_for_metrics,
@@ -613,19 +616,12 @@ class OnboardingDataAssistant(DataAssistant):
 
         # Step-2: Declare "ParameterBuilder" for every metric of interest.
 
-        column_partition_parameter_builder_for_metrics: ParameterBuilder = DataAssistant.commonly_used_parameter_builders.build_partition_parameter_builder(
-            name="column_values.partition",
-            bucketize_data=False,
-        )
         column_min_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
             DataAssistant.commonly_used_parameter_builders.get_column_min_metric_multi_batch_parameter_builder()
         )
         column_max_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
             DataAssistant.commonly_used_parameter_builders.get_column_max_metric_multi_batch_parameter_builder()
         )
-        column_quantile_values_metric_multi_batch_parameter_builder_for_metrics: ParameterBuilder = (
-            DataAssistant.commonly_used_parameter_builders.get_column_quantile_values_metric_multi_batch_parameter_builder()
-        )
 
         # Step-3: Declare "ParameterBuilder" for every "validation" need in "ExpectationConfigurationBuilder" objects.
 
@@ -653,20 +649,6 @@ class OnboardingDataAssistant(DataAssistant):
             evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
         )
 
-        evaluation_parameter_builder_configs = [
-            ParameterBuilderConfig(
-                **column_quantile_values_metric_multi_batch_parameter_builder_for_metrics.to_json_dict()
-            ),
-        ]
-        column_quantile_values_range_parameter_builder_for_validations: ParameterBuilder = DataAssistant.commonly_used_parameter_builders.build_numeric_metric_range_multi_batch_parameter_builder(
-            metric_name=None,
-            metric_value_kwargs={
-                "quantiles": f"{VARIABLES_KEY}quantiles",
-                "allow_relative_error": f"{VARIABLES_KEY}allow_relative_error",
-            },
-            evaluation_parameter_builder_configs=evaluation_parameter_builder_configs,
-        )
-
         # Step-4: Pass "validation" "ParameterBuilderConfig" objects to every "DefaultExpectationConfigurationBuilder", responsible for emitting "ExpectationConfiguration" (with specified "expectation_type").
 
         validation_parameter_builder_configs: Optional[List[ParameterBuilderConfig]]
@@ -732,37 +714,12 @@ class OnboardingDataAssistant(DataAssistant):
             },
         )
 
-        validation_parameter_builder_configs = [
-            ParameterBuilderConfig(
-                **column_quantile_values_range_parameter_builder_for_validations.to_json_dict(),
-            ),
-        ]
-        expect_column_quantile_values_to_be_between_expectation_configuration_builder = DefaultExpectationConfigurationBuilder(
-            expectation_type="expect_column_quantile_values_to_be_between",
-            validation_parameter_builder_configs=validation_parameter_builder_configs,
-            column=f"{DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}column",
-            quantile_ranges={
-                "quantiles": f"{VARIABLES_KEY}quantiles",
-                "value_ranges": f"{column_quantile_values_range_parameter_builder_for_validations.json_serialized_fully_qualified_parameter_name}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}{FULLY_QUALIFIED_PARAMETER_NAME_VALUE_KEY}",
-            },
-            allow_relative_error=f"{VARIABLES_KEY}allow_relative_error",
-            meta={
-                "profiler_details": f"{column_quantile_values_range_parameter_builder_for_validations.json_serialized_fully_qualified_parameter_name}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}{FULLY_QUALIFIED_PARAMETER_NAME_METADATA_KEY}",
-            },
-        )
-
         # Step-5: Instantiate and return "Rule" object, comprised of "variables", "domain_builder", "parameter_builders", and "expectation_configuration_builders" components.
 
         variables: dict = {
             "mostly": 1.0,
             "strict_min": False,
             "strict_max": False,
-            "quantiles": [
-                0.25,
-                0.5,
-                0.75,
-            ],
-            "allow_relative_error": False,
             "false_positive_rate": 0.05,
             "estimator": "bootstrap",
             "n_resamples": 9999,
@@ -775,19 +732,16 @@ class OnboardingDataAssistant(DataAssistant):
                 "lower_bound": None,
                 "upper_bound": None,
             },
-            "round_decimals": 1,
+            "round_decimals": None,
         }
         parameter_builders: List[ParameterBuilder] = [
-            column_partition_parameter_builder_for_metrics,
             column_min_metric_multi_batch_parameter_builder_for_metrics,
             column_max_metric_multi_batch_parameter_builder_for_metrics,
-            column_quantile_values_metric_multi_batch_parameter_builder_for_metrics,
         ]
         expectation_configuration_builders: List[ExpectationConfigurationBuilder] = [
             expect_column_min_to_be_between_expectation_configuration_builder,
             expect_column_max_to_be_between_expectation_configuration_builder,
             expect_column_values_to_be_between_expectation_configuration_builder,
-            expect_column_quantile_values_to_be_between_expectation_configuration_builder,
         ]
         rule = Rule(
             name="datetime_columns_rule",
@@ -1100,7 +1054,7 @@ class OnboardingDataAssistant(DataAssistant):
                 "lower_bound": 0.0,
                 "upper_bound": None,
             },
-            "round_decimals": 15,
+            "round_decimals": None,
         }
         parameter_builders: List[ParameterBuilder] = [
             column_distinct_values_count_metric_multi_batch_parameter_builder_for_metrics,
