@@ -1,5 +1,6 @@
 import os
 
+import pytest
 from click.testing import CliRunner
 
 from great_expectations import DataContext
@@ -24,6 +25,7 @@ def test_docs_help_output(caplog):
 
 
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
+@pytest.mark.slow  # 2.53s
 def test_docs_build_view(
     mock_webbrowser, caplog, site_builder_data_context_with_html_store_titanic_random
 ):
@@ -62,6 +64,7 @@ def test_docs_build_view(
 
 
 @mock.patch("webbrowser.open", return_value=True, side_effect=None)
+@pytest.mark.slow  # 2.52s
 def test_docs_build_no_view(
     mock_webbrowser, caplog, site_builder_data_context_with_html_store_titanic_random
 ):
@@ -102,6 +105,7 @@ def test_docs_build_no_view(
     )
 
 
+@pytest.mark.slow  # 2.40s
 def test_docs_build_assume_yes(
     caplog, site_builder_data_context_with_html_store_titanic_random
 ):
