@@ -20,7 +20,8 @@ from tests.test_utils import create_files_in_directory
 yaml = YAML()
 
 
-@pytest.mark.unit
+@pytest.mark.integration
+@pytest.mark.slow  # 1.05s
 def test__get_full_file_path_for_asset_pandas(fs):
     """
     What does this test and why?
@@ -134,6 +135,7 @@ def test__get_full_file_path_for_asset_pandas(fs):
     assert batch_spec.path == f"{base_directory}/test_dir_0/A/B/C/logfile_0.csv"
 
 
+@pytest.mark.integration
 def test__get_full_file_path_for_asset_spark(basic_spark_df_execution_engine, fs):
     """
     What does this test and why?
