@@ -181,7 +181,9 @@ def test_atomic_prescriptive_summary_expect_column_kl_divergence_to_be_less_than
     pprint(res)
 
     # replace version of vega-lite in res to match snapshot test
-    res["value"]["graph"] = re.sub(r"v\d*\.\d*\.\d*", "v4.8.1", res["value"]["graph"])
+    res["value"]["graph"]["$schema"] = re.sub(
+        r"v\d*\.\d*\.\d*", "v4.8.1", res["value"]["graph"]["$schema"]
+    )
 
     snapshot.assert_match(res)
 
@@ -226,7 +228,9 @@ def test_atomic_diagnostic_observed_value_expect_column_kl_divergence_to_be_less
     pprint(res)
 
     # replace version of vega-lite in res to match snapshot test
-    res["value"]["graph"] = re.sub(r"v\d*\.\d*\.\d*", "v4.8.1", res["value"]["graph"])
+    res["value"]["graph"]["$schema"] = re.sub(
+        r"v\d*\.\d*\.\d*", "v4.8.1", res["value"]["graph"]["$schema"]
+    )
     snapshot.assert_match(res)
 
 
