@@ -28,6 +28,8 @@ yaml = YAML(typ="safe")
 
 
 # noinspection PyPep8Naming
+@pytest.mark.integration
+@pytest.mark.slow  # 1.15s
 def test_table_domain_builder(
     alice_columnar_table_single_batch_context,
     table_Users_domain,
@@ -54,6 +56,7 @@ def test_table_domain_builder(
     assert domain.kwargs is None
 
 
+@pytest.mark.integration
 def test_builder_executed_with_runtime_batch_request_does_not_raise_error(
     data_context_with_datasource_pandas_engine,
     alice_columnar_table_single_batch,
@@ -124,6 +127,8 @@ def test_builder_executed_with_runtime_batch_request_does_not_raise_error(
     ]
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.21s
 def test_column_domain_builder(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
@@ -242,6 +247,8 @@ def test_column_domain_builder(
     ]
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.20s
 def test_column_domain_builder_with_simple_semantic_type_included(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
@@ -306,6 +313,8 @@ def test_column_domain_builder_with_simple_semantic_type_included(
     ]
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.19s
 def test_column_pair_domain_builder_wrong_column_names(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
@@ -340,7 +349,7 @@ def test_column_pair_domain_builder_wrong_column_names(
     )
 
     with pytest.raises(ge_exceptions.ProfilerExecutionError) as excinfo:
-        # noinspection PyArgumentList
+        # noinspection PyUnusedLocal
         domains: List[Domain] = domain_builder.get_domains(
             rule_name="my_rule", variables=variables, batch_request=batch_request
         )
@@ -351,6 +360,8 @@ def test_column_pair_domain_builder_wrong_column_names(
     )
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.19s
 def test_column_pair_domain_builder_correct_sorted_column_names(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
@@ -413,6 +424,8 @@ def test_column_pair_domain_builder_correct_sorted_column_names(
     assert domain.domain_kwargs.column_B == "user_id"
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.30s
 def test_multi_column_domain_builder_wrong_column_list(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
@@ -443,7 +456,7 @@ def test_multi_column_domain_builder_wrong_column_list(
     )
 
     with pytest.raises(ge_exceptions.ProfilerExecutionError) as excinfo:
-        # noinspection PyArgumentList
+        # noinspection PyUnusedLocal
         domains: List[Domain] = domain_builder.get_domains(
             rule_name="my_rule", variables=variables, batch_request=batch_request
         )
@@ -453,7 +466,7 @@ def test_multi_column_domain_builder_wrong_column_list(
     )
 
     with pytest.raises(ge_exceptions.ProfilerExecutionError) as excinfo:
-        # noinspection PyArgumentList
+        # noinspection PyUnusedLocal
         domains: List[Domain] = domain_builder.get_domains(
             rule_name="my_rule", variables=variables, batch_request=batch_request
         )
@@ -463,6 +476,8 @@ def test_multi_column_domain_builder_wrong_column_list(
     )
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.18s
 def test_multi_column_domain_builder_correct_column_list(
     alice_columnar_table_single_batch_context,
     alice_columnar_table_single_batch,
