@@ -18,6 +18,8 @@ from great_expectations.rule_based_profiler.parameter_container import (
 )
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.08s
 def test_instantiation_value_set_multi_batch_parameter_builder(
     alice_columnar_table_single_batch_context,
 ):
@@ -32,6 +34,8 @@ def test_instantiation_value_set_multi_batch_parameter_builder(
     )
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.07s
 def test_instantiation_value_set_multi_batch_parameter_builder_no_name(
     alice_columnar_table_single_batch_context,
 ):
@@ -49,6 +53,8 @@ def test_instantiation_value_set_multi_batch_parameter_builder_no_name(
     )
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.19s
 def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
     alice_columnar_table_single_batch_context,
 ):
@@ -121,6 +127,8 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_numeric(
     assert parameter_node.details == expected_parameter_value["details"]
 
 
+@pytest.mark.integration
+@pytest.mark.slow  # 1.20s
 def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
     alice_columnar_table_single_batch_context,
 ):
@@ -199,6 +207,7 @@ def test_value_set_multi_batch_parameter_builder_alice_single_batch_string(
     assert parameter_node.details == expected_parameter_value["details"]
 
 
+@pytest.mark.integration
 def test_value_set_multi_batch_parameter_builder_bobby_numeric(
     bobby_columnar_table_multi_batch_deterministic_data_context,
 ):
@@ -276,6 +285,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_numeric(
     assert parameter_node.details == expected_parameter_value["details"]
 
 
+@pytest.mark.integration
 def test_value_set_multi_batch_parameter_builder_bobby_string(
     bobby_columnar_table_multi_batch_deterministic_data_context,
 ):
@@ -374,6 +384,7 @@ def test_value_set_multi_batch_parameter_builder_bobby_string(
         ],
     ],
 )
+@pytest.mark.unit
 def test__get_unique_values_from_nested_collection_of_sets(test_input, expected):
     """
     What does this test and why?
