@@ -10,6 +10,8 @@ class MyCustomStoreBackend(TupleStoreBackend):
         forbidden_substrings=None,
         platform_specific_separator=True,
         fixed_length_key=False,
+        suppress_store_backend_id=False,
+        store_name=None,
     ):
         super().__init__(
             filepath_template=filepath_template,
@@ -18,6 +20,8 @@ class MyCustomStoreBackend(TupleStoreBackend):
             forbidden_substrings=forbidden_substrings,
             platform_specific_separator=platform_specific_separator,
             fixed_length_key=fixed_length_key,
+            suppress_store_backend_id=suppress_store_backend_id,
+            store_name=store_name,
         )
 
     def _get(self, key):
