@@ -187,7 +187,7 @@ def test_validate(empty_data_context):
         file_relative_path(__file__, "./test_sets/titanic_expectations.json")
     ) as f:
         my_expectation_suite_dict: dict = expectationSuiteSchema.loads(f.read())
-        my_expectation_suite: ExpectationSuite = ExpectationSuite(
+        my_expectation_suite = ExpectationSuite(
             **my_expectation_suite_dict, data_context=context
         )
 
@@ -275,7 +275,7 @@ def test_validate_with_invalid_result_catch_exceptions_false(empty_data_context)
         file_relative_path(__file__, "./test_sets/titanic_expectations.json")
     ) as f:
         my_expectation_suite_dict: dict = expectationSuiteSchema.loads(f.read())
-        my_expectation_suite: ExpectationSuite = ExpectationSuite(
+        my_expectation_suite = ExpectationSuite(
             **my_expectation_suite_dict, data_context=context
         )
 
@@ -303,7 +303,7 @@ def test_validate_with_invalid_result(empty_data_context):
         file_relative_path(__file__, "./test_sets/titanic_expectations.json")
     ) as f:
         my_expectation_suite_dict: dict = expectationSuiteSchema.loads(f.read())
-        my_expectation_suite: ExpectationSuite = ExpectationSuite(
+        my_expectation_suite = ExpectationSuite(
             **my_expectation_suite_dict, data_context=context
         )
 
@@ -468,7 +468,7 @@ class TestIO(unittest.TestCase):
     def test_read_excel(self):
         script_path = os.path.dirname(os.path.realpath(__file__))
         df = ge.read_excel(
-            script_path + "/test_sets/Titanic_multi_sheet.xlsx",
+            script_path + "/test_sets/Titanic_multi_sheet.xlsx", engine="openpyxl"
         )
         assert df["Name"][0] == "Allen, Miss Elisabeth Walton"
         assert isinstance(df, PandasDataset)
@@ -478,12 +478,16 @@ class TestIO(unittest.TestCase):
         pandas_version = pd.__version__
         if re.match(r"0\.2[012]\.", pandas_version) is not None:
             dfs_dict = ge.read_excel(
-                script_path + "/test_sets/Titanic_multi_sheet.xlsx", sheetname=None
+                script_path + "/test_sets/Titanic_multi_sheet.xlsx",
+                sheetname=None,
+                engine="openpyxl",
             )
 
         else:
             dfs_dict = ge.read_excel(
-                script_path + "/test_sets/Titanic_multi_sheet.xlsx", sheet_name=None
+                script_path + "/test_sets/Titanic_multi_sheet.xlsx",
+                sheet_name=None,
+                engine="openpyxl",
             )
         assert isinstance(dfs_dict, dict)
         assert list(dfs_dict.keys()) == ["Titanic_1", "Titanic_2", "Titanic_3"]
