@@ -131,6 +131,7 @@ def yellow_trip_pandas_data_context(
     return context
 
 
+@pytest.mark.integration
 def test_parse_validation_graph():
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, 6]})
     expectation_configuration = ExpectationConfiguration(
@@ -170,6 +171,7 @@ def test_parse_validation_graph():
 
 
 # Should be passing tests even if given incorrect MetricProvider data
+@pytest.mark.integration
 def test_parse_validation_graph_with_bad_metrics_args():
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, 6]})
     expectation_configuration = ExpectationConfiguration(
@@ -208,6 +210,7 @@ def test_parse_validation_graph_with_bad_metrics_args():
     assert len(ready_metrics) == 2 and len(needed_metrics) == 9
 
 
+@pytest.mark.integration
 def test_populate_dependencies():
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, 6]})
     expectation_configuration = ExpectationConfiguration(
@@ -246,6 +249,7 @@ def test_populate_dependencies():
     assert len(graph.edges) == 33
 
 
+@pytest.mark.integration
 def test_populate_dependencies_with_incorrect_metric_name():
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, 6]})
     expectation_configuration = ExpectationConfiguration(
@@ -289,6 +293,7 @@ def test_populate_dependencies_with_incorrect_metric_name():
     assert isinstance(graph, ge_exceptions.MetricProviderError)
 
 
+@pytest.mark.integration
 def test_graph_validate(basic_datasource):
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, None]})
 
@@ -341,6 +346,7 @@ def test_graph_validate(basic_datasource):
     ]
 
 
+@pytest.mark.integration
 def test_graph_validate_with_exception(basic_datasource):
     def mock_error(*args, **kwargs):
         raise Exception("Mock Error")
@@ -384,6 +390,7 @@ def test_graph_validate_with_exception(basic_datasource):
     assert result[0].expectation_config is not None
 
 
+@pytest.mark.integration
 def test_graph_validate_with_bad_config_catch_exceptions_false(basic_datasource):
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, None]})
 
@@ -426,6 +433,7 @@ def test_graph_validate_with_bad_config_catch_exceptions_false(basic_datasource)
     )
 
 
+@pytest.mark.integration
 def test_resolve_validation_graph_with_bad_config_catch_exceptions_true(
     basic_datasource,
 ):
@@ -504,6 +512,7 @@ def test_resolve_validation_graph_with_bad_config_catch_exceptions_true(
 
 
 # Tests that runtime configuration actually works during graph validation
+@pytest.mark.integration
 def test_graph_validate_with_runtime_config(basic_datasource):
     df = pd.DataFrame(
         {"a": [1, 5, 22, 3, 5, 10, 2, 3], "b": [97, 332, 3, 4, 5, 6, 7, None]}
@@ -573,6 +582,7 @@ def test_graph_validate_with_runtime_config(basic_datasource):
     ]
 
 
+@pytest.mark.integration
 def test_validator_default_expectation_args__pandas(basic_datasource):
     df = pd.DataFrame({"a": [1, 5, 22, 3, 5, 10], "b": [1, 2, 3, 4, 5, None]})
 
@@ -599,6 +609,7 @@ def test_validator_default_expectation_args__pandas(basic_datasource):
     print(my_validator.get_default_expectation_arguments())
 
 
+@pytest.mark.integration
 def test_validator_default_expectation_args__sql(
     data_context_with_simple_sql_datasource_for_testing_get_batch,
 ):
@@ -637,6 +648,7 @@ def test_validator_default_expectation_args__sql(
         )
 
 
+@pytest.mark.integration
 def test_columns(
     titanic_pandas_data_context_with_v013_datasource_stats_enabled_with_checkpoints_v1_with_templates,
 ):
@@ -664,6 +676,7 @@ def test_columns(
     assert columns == expected
 
 
+@pytest.mark.integration
 def test_head(
     titanic_pandas_data_context_with_v013_datasource_stats_enabled_with_checkpoints_v1_with_templates,
 ):
@@ -759,7 +772,6 @@ def multi_batch_taxi_validator_ge_cloud_mode(
     return validator_multi_batch
 
 
-@pytest.mark.cloud
 @mock.patch(
     "great_expectations.data_context.data_context.BaseDataContext.save_expectation_suite"
 )
@@ -769,6 +781,8 @@ def multi_batch_taxi_validator_ge_cloud_mode(
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
+@pytest.mark.cloud
+@pytest.mark.integration
 def test_ge_cloud_validator_updates_self_suite_with_ge_cloud_ids_on_save(
     mock_emit,
     mock_context_get_suite,
@@ -818,6 +832,7 @@ def test_ge_cloud_validator_updates_self_suite_with_ge_cloud_ids_on_save(
     assert mock_emit.call_args_list == []
 
 
+@pytest.mark.integration
 def test_validator_can_instantiate_with_a_multi_batch_request(
     multi_batch_taxi_validator,
 ):
@@ -839,6 +854,7 @@ def test_validator_can_instantiate_with_a_multi_batch_request(
     ]
 
 
+@pytest.mark.integration
 def test_validator_with_bad_batchrequest(
     yellow_trip_pandas_data_context,
 ):
@@ -858,6 +874,7 @@ def test_validator_with_bad_batchrequest(
         )
 
 
+@pytest.mark.integration
 def test_validator_batch_filter(
     multi_batch_taxi_validator,
 ):
@@ -947,6 +964,7 @@ def test_validator_batch_filter(
     )
 
 
+@pytest.mark.integration
 def test_custom_filter_function(
     multi_batch_taxi_validator,
 ):
@@ -979,6 +997,7 @@ def test_custom_filter_function(
 @mock.patch(
     "great_expectations.core.usage_statistics.usage_statistics.UsageStatisticsHandler.emit"
 )
+@pytest.mark.integration
 def test_adding_expectation_to_validator_not_send_usage_message(
     mock_emit, multi_batch_taxi_validator
 ):
@@ -997,6 +1016,8 @@ def test_adding_expectation_to_validator_not_send_usage_message(
     assert mock_emit.call_args_list == []
 
 
+@pytest.mark.slow  # 2.53s
+@pytest.mark.integration
 def test_validator_set_active_batch(
     multi_batch_taxi_validator,
 ):
@@ -1025,6 +1046,7 @@ def test_validator_set_active_batch(
         ).success
 
 
+@pytest.mark.integration
 def test_validator_load_additional_batch_to_validator(
     yellow_trip_pandas_data_context,
 ):
@@ -1073,6 +1095,7 @@ def test_validator_load_additional_batch_to_validator(
     assert first_batch_markers != updated_batch_markers
 
 
+@pytest.mark.integration
 def test_instantiate_validator_with_a_list_of_batch_requests(
     yellow_trip_pandas_data_context,
 ):
@@ -1131,6 +1154,7 @@ def test_instantiate_validator_with_a_list_of_batch_requests(
     )
 
 
+@pytest.mark.integration
 def test_validate_expectation(multi_batch_taxi_validator):
     validator: Validator = multi_batch_taxi_validator
     expect_column_values_to_be_between_config = validator.validate_expectation(
@@ -1157,6 +1181,7 @@ def test_validate_expectation(multi_batch_taxi_validator):
 @mock.patch("great_expectations.data_context.data_context.DataContext")
 @mock.patch("great_expectations.validator.validation_graph.ValidationGraph")
 @mock.patch("great_expectations.validator.validator.tqdm")
+@pytest.mark.unit
 def test_validator_progress_bar_config_enabled(
     mock_tqdm, mock_validation_graph, mock_data_context
 ):
@@ -1176,6 +1201,7 @@ def test_validator_progress_bar_config_enabled(
 @mock.patch("great_expectations.data_context.data_context.DataContext")
 @mock.patch("great_expectations.validator.validation_graph.ValidationGraph")
 @mock.patch("great_expectations.validator.validator.tqdm")
+@pytest.mark.unit
 def test_validator_progress_bar_config_disabled(
     mock_tqdm, mock_validation_graph, mock_data_context
 ):
@@ -1192,6 +1218,7 @@ def test_validator_progress_bar_config_disabled(
     assert mock_tqdm.call_args[1]["disable"] is True
 
 
+@pytest.mark.integration
 def test_validator_docstrings(multi_batch_taxi_validator):
     expectation_impl = getattr(
         multi_batch_taxi_validator, "expect_column_values_to_be_in_set", None
@@ -1201,6 +1228,7 @@ def test_validator_docstrings(multi_batch_taxi_validator):
     )
 
 
+@pytest.mark.integration
 def test_validator_include_rendered_content(
     yellow_trip_pandas_data_context,
 ):
@@ -1250,6 +1278,7 @@ def test_validator_include_rendered_content(
     assert isinstance(validation_result.rendered_content[0], RenderedAtomicContent)
 
 
+@pytest.mark.integration
 def test_validator_include_rendered_content_evaluation_parameters(
     yellow_trip_pandas_data_context,
 ):
@@ -1298,3 +1327,76 @@ def test_validator_include_rendered_content_evaluation_parameters(
         ]
         == 8000
     )
+
+
+@pytest.fixture
+def validator_with_mock_execution_engine() -> Validator:
+    execution_engine = mock.MagicMock()
+    validator = Validator(execution_engine=execution_engine)
+    return validator
+
+
+@pytest.mark.unit
+def test___dir___contains_expectation_impls(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    attrs = validator.__dir__()
+    expectation_impls = list(filter(lambda a: a.startswith("expect_"), attrs))
+    assert len(expectation_impls) > 0
+
+
+@pytest.mark.unit
+def test_show_progress_bars_property_and_setter(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    assert validator.show_progress_bars is True
+    validator.show_progress_bars = False
+    assert validator.show_progress_bars is False
+
+
+@pytest.mark.unit
+def test_expose_dataframe_methods_property_and_setter(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    assert validator.expose_dataframe_methods is False
+    validator.expose_dataframe_methods = True
+    assert validator.expose_dataframe_methods is True
+
+
+@pytest.mark.unit
+def test___get_attr___retrieves_existing_expectation(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    # Does not raise error if properly registered
+    # Avoiding invocation to only test registration (and not actual expectation)
+    validator.expect_column_max_to_be_between
+
+
+@pytest.mark.unit
+def test__get_attr___raises_attribute_error_with_invalid_attr(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    with pytest.raises(AttributeError) as e:
+        validator.my_fake_attr
+
+    assert "'Validator'  object has no attribute 'my_fake_attr'" in str(e.value)
+
+
+@pytest.mark.unit
+def test_list_available_expectation_types(
+    validator_with_mock_execution_engine: Validator,
+) -> None:
+    validator = validator_with_mock_execution_engine
+
+    available = validator.list_available_expectation_types()
+    assert all(e.startswith("expect_") for e in available)
